==> mpd-4.4.tar.gz: mpd-4.4/src/msgdef.h <==

/*
 * msgdef.h
 *
 * Written by Archie Cobbs <archie@freebsd.org>
 * Copyright (c) 1995-1999 Whistle Communications, Inc. All rights reserved.
 * See ``COPYRIGHT.whistle''
 */

#define STR_READY_TO_DIAL	"Ready to dial."
#define STR_REDIAL		"Redial"
#define STR_DEMAND		"Demand"
#define STR_IDLE_TIMEOUT	"Idle timeout"
#define STR_SESSION_TIMEOUT	"Session timeout"
#define STR_COPY		"%s"
#define STR_CHAT_SCRIPT_FAILED	"Chat script failed"
#define STR_CON_FAILED0		"Connection failed"
#define STR_WAIT_CALL		"Waiting for connection."
#define STR_CONNECT_TO		"Connecting to %s..."
#define STR_CON_FAILED		"Connection failed: %s"
#define STR_DROPPED		"Dropped"
#define STR_PEER_DISC		"Peer disconnect"
#define STR_CONN_ESTAB		"Network connection established."
#define STR_PROTO_ERR		"Protocol error"
#define STR_LOGIN_FAIL		"Login failed"
#define STR_ECHO_TIMEOUT	"Echo timeout"
#define STR_MANUALLY		"Manual"
#define STR_RINGBACK		"Ringback"
#define STR_ADMIN_SHUTDOWN	"Admin shutdown"
#define STR_FATAL_SHUTDOWN	"Fatal shutdown"
#define STR_INCOMING_CALL	"Incoming call"
#define STR_PPP_DISABLED	"Port disabled."
#define STR_ERROR		"Error"
#define STR_PORT_NEEDED		"Increased demand"
#define STR_PORT_UNNEEDED	"Decreased demand"

#define STR_IPCP_FAILED		"PPP layer IPCP failed: %s"
#define STR_IPV6CP_FAILED	"PPP layer IPV6CP failed: %s"

#define STR_FAIL_NEGOT_FAILURE	"parameter negotiation failed"
#define STR_FAIL_RECD_BADMAGIC	"received an invalid magic number"
#define STR_FAIL_RECD_CODEREJ	"received fatal code reject"
#define STR_FAIL_RECD_PROTREJ	"received fatal protocol reject"
#define STR_FAIL_WAS_PROTREJ	"protocol was rejected by peer"
#define STR_FAIL_ECHO_TIMEOUT	"peer not responding to echo requests"
#define STR_FAIL_CANT_ENCRYPT	"failed to negotiate required encryption"
#define STR_LCP_FAILED		"PPP layer LCP failed: %s"
#define STR_LOST_DSR		"Lost modem data-set ready signal"
#define STR_LOST_CD		"Lost modem carrier detect signal"
#define STR_DEV_NOT_READY	"Device not ready"

#define STR_PPP_AUTH_FAILURE	"PPP authorization failed."
#define STR_PPP_AUTH_FAILURE2	"PPP authorization failed. The login or password configured for this port was not accepted by the server."
#define STR_MULTI_FAIL		"Multi-link PPP negotiation failure."

#define STR_LINK_ESTAB		"Establishing link..."
#define STR_LINK_AUTH		"Authenticating..."
#define STR_LINK_NEGOT		"Negotiating network addresses..."
#define STR_LINK_CONN_ESTAB	"Network connection established."
#define STR_LINK_HANGUP		"Hanging up..."
#define STR_LINK_DISCON		"Disconnected."

==> mpd4-4.0b4.tar.gz: mpd4-4.0b4/src/msgdef.h <==

/*
 * msgdef.h
 *
 * Written by Archie Cobbs <archie@freebsd.org>
 * Copyright (c) 1995-1999 Whistle Communications, Inc. All rights reserved.
 * See ``COPYRIGHT.whistle''
 */

#define STR_READY_TO_DIAL	"Ready to dial."
#define STR_REDIAL		"Redial"
#define STR_DEMAND		"Demand"
#define STR_IDLE_TIMEOUT	"Idle timeout"
#define STR_SESSION_TIMEOUT	"Session timeout"
#define STR_COPY		"%s"
#define STR_CHAT_SCRIPT_FAILED	"Chat script failed"
#define STR_CON_FAILED0		"Connection failed"
#define STR_QUIT		"Quit from console"
#define STR_WAIT_CALL		"Waiting for connection."
#define STR_CONNECT_TO		"Connecting to %s..."
#define STR_CON_FAILED		"Connection failed: %s"
#define STR_DROPPED		"Dropped"
#define STR_READ_ERR		"Read error"
#define STR_READ_EOF		"Read EOF"
#define STR_WRITE_ERR		"Write error"
#define STR_PEER_DISC		"Peer disconnect"
#define STR_CONN_ESTAB		"Network connection established."
#define STR_PROTO_ERR		"Protocol error"
#define STR_LOGIN_FAIL		"Login failed"
#define STR_ECHO_TIMEOUT	"Echo timeout"
#define STR_MANUALLY		"Manually"
#define STR_RINGBACK		"Ringback"
#define STR_PORT_SHUTDOWN	"Port shutdown"
#define STR_INCOMING_CALL	"Incoming call"
#define STR_PPP_DISABLED	"Port disabled."
#define STR_ERROR		"Error"
#define STR_UNKNOWN		"Unknown"
#define STR_UNKNOWN_REASON	"unknown reason"

#define STR_PEER_DISCONNECT	"The remote server initiated a disconnection for unknown reasons."
#define STR_IPCP_FAILED		"PPP layer IPCP failed: %s"

#define STR_FAIL_NEGOT_FAILURE	"parameter negotiation failed"
#define STR_FAIL_RECD_BADMAGIC	"received an invalid magic number"
#define STR_FAIL_RECD_CODEREJ	"received fatal code reject"
#define STR_FAIL_RECD_PROTREJ	"received fatal protocol reject"
#define STR_FAIL_WAS_PROTREJ	"protocol was rejected by peer"
#define STR_FAIL_ECHO_TIMEOUT	"peer not responding to echo requests"
#define STR_FAIL_CANT_ENCRYPT	"failed to negotiate required encryption"
#define STR_LCP_FAILED		"PPP layer LCP failed: %s"
#define STR_LOST_DSR		"Lost modem data-set ready signal"
#define STR_LOST_CD		"Lost modem carrier detect signal"
#define STR_DEV_NOT_READY	"Device not ready"

#define STR_PPP_AUTH_FAILURE	"PPP authorization failed."
#define STR_PPP_AUTH_FAILURE2	"PPP authorization failed. The login or password configured for this port was not accepted by the server."
#define STR_MULTI_FAIL		"Multi-link PPP negotiation failure."

#define STR_LINK_ESTAB		"Establishing link..."
#define STR_LINK_AUTH		"Authenticating..."
#define STR_LINK_NEGOT		"Negotiating network addresses..."
#define STR_LINK_CONN_ESTAB	"Network connection established."
#define STR_LINK_HANGUP		"Hanging up..."
#define STR_LINK_DISCON		"Disconnected."
